#include <RFM69.h>
#include <RFM69registers.h>
#include <Wire.h>
#include <SPI.h>
#include <Adafruit_LIS3DH.h>
#include <Adafruit_Sensor.h>

// Adjust this number for the sensitivity of the 'click' force
// this strongly depend on the range! for 16G, try 5-10
// for 8G, try 10-20. for 4G try 20-40. for 2G try 40-80
#define CLICKTHRESHHOLD 80

#define NETWORKID     0   // Must be the same for all nodes
#define MYNODEID      1   // My node IDnn
#define TONODEID      2   // Destination node ID

// RFM69 frequency, uncomment the frequency of your module:
#define FREQUENCY   RF69_433MHZ
//#define FREQUENCY     RF69_915MHZ

#define ENCRYPTKEY    "TOPSECRETPASSWRD" // Use the same 16-byte key on all nodes
#define IS_RFM69HCW   true // set to 'true' if you are using an RFM69HCW module

#define RFM69_CS      10
#define RFM69_IRQ     3
#define RFM69_IRQN    3  // Pin 3 is IRQ 3!
#define RFM69_RST     9

// Create a library object for our RFM69HCW module:
RFM69 radio = RFM69(RFM69_CS, RFM69_IRQ, IS_RFM69HCW, RFM69_IRQ);

Adafruit_LIS3DH lis = Adafruit_LIS3DH();

IntervalTimer myTimer;

static char sendbuffer[64];
int buffersize;

uint8_t data;
const int audio =  A12;
const int MIC =  A1;

void setup()
{                
  Serial.begin(115200);
  //Serial1.begin(115200);
  analogReadResolution(8);
  pinMode(MIC, INPUT);

  if (! lis.begin(0x18)) {   // change this to 0x19 for alternative i2c address
    Serial.println("Couldnt start LIS3DH");
    while (1);
  }
  
  lis.setRange(LIS3DH_RANGE_2_G);   // 2, 4, 8 or 16 G!

  // 0 = turn off click detection & interrupt
  // 1 = single click only interrupt output
  // 2 = double click only interrupt output, detect single click
  // Adjust threshhold, higher numbers are less sensitive
  lis.setClick(1, CLICKTHRESHHOLD);
  
  //
  // Hard Reset the RFM module
  //
  pinMode(RFM69_RST, OUTPUT);
  digitalWrite(RFM69_RST, HIGH);
  delay(100);
  digitalWrite(RFM69_RST, LOW);
  delay(100);
  
  radio.initialize(FREQUENCY, MYNODEID, NETWORKID);
  radio.setHighPower(); // Always use this for RFM69HCW
  //radio.encrypt(ENCRYPTKEY);
  radio.streamingMode();

  buffersize = 64;
  for(int i = 0; i<64;i++) {
    sendbuffer[i] = 0xAA;
  }
 
  delay(1000);
  radio.stream(TONODEID, sendbuffer, buffersize);
  myTimer.begin(sendData, 80);  // 64 us = 15.625 kHz
  data = 0;
}

void loop()                     
{
  delay(200);
  if(digitalRead(RFM69_IRQ))
    radio.stream(TONODEID, sendbuffer, buffersize);
  //sendData();
}

void sendData()
{
  if(!digitalRead(RFM69_IRQ))
  {
    data = analogRead(MIC);
    //Serial.println(data);
    radio.sendStreamByte(data);
    analogWrite(audio, data);
    //data = data + 32;
  }
}

